


04/16/93 E. Correia
WK#:581       MV#:3c
Breitkopf & Hărtel, Vol. 13 
Clarinet Quintet
Trio II
Violino I
1 0 
Group memberships: sound, score
sound: part 2 of 5
score: part 2 of 5
$  K:3   Q:2   T:3/4   C:4
rest   2        q
measure 1
rest   2        q
A4     2        q     u        p
A4     2        q     u
measure 2
rest   2        q
A4     2        q     u
A4     2        q     u
measure 3
rest   2        q
G#4    2        q     u
G#4    2        q     u
measure 4
rest   2        q
A4     2        q     u
A4     2        q     u
measure 5
rest   2        q
A4     2        q     u
A4     2        q     u
measure 6
F#4    2        q     u
rest   2        q
C#5    1        e     d  [     (
A#4    1        e #   d  ]
measure 7
B4     1        e     d  [
D5     1        e     d  ]
F#5    2        q     d        )
C#5    1        e     d  [     (
A#4    1        e #   d  ]
measure 8
B4     1        e     d  [
D5     1        e     d  ]
F#5    2        q     d        )
rest   2        q
measure 9
rest   6
measure 10
rest   6
measure 11
C#4    1        e     u  [     (
E4     1        e     u  =
C#4    1        e     u  =
E4     1        e     u  =
D4     1        e     u  =
E4     1        e     u  ]     )
measure 12
C#4    2        q     u
rest   2        q
mheavy4         :||:
/END